#
# spec file for package gnome-keysign
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-keysign
Version:        0.9.7.2
Release:        2.11
Summary:        GNOME OpenGPG key signing helper
License:        GPL-3.0-or-later
Group:          Productivity/Security
Url:            https://github.com/GNOME-Keysign/gnome-keysign
Source:         %{name}-%{version}.tar.xz
Patch0:         gnome-keysign-python3-setup.patch

BuildRequires:  gobject-introspection
BuildRequires:  python3-Babel
BuildRequires:  python3-lxml
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
%ifarch aarch64 ppc64 ppc64le riscv64 s390x x86_64
Requires:       gstreamer1(element-zbar)()(64bit)
%else
Requires:       gstreamer1(element-zbar)
%endif
Requires:       python3-Twisted
Requires:       python3-avahi
Requires:       python3-cairo
Requires:       python3-dbus-python
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-gpg
Requires:       python3-pybluez
Requires:       python3-qrcode
Requires:       python3-requests
Requires:       python3-setuptools

%description
Its purpose is to ease signing other peoples' keys. It is similar
to caff, PIUS, or monkeysign. In fact, it is influenced a lot by
these tools and either reimplements ideas or reuses code.
Consider either of the aboved mentioned tools when you need a much
more mature codebase.

%prep
%setup -q
%patch0 -p1

%build
python3 setup.py build

%install
python3 setup.py install -O1 --skip-build --root %{buildroot}
%suse_update_desktop_file -r org.gnome.Keysign System Security

%files
%license COPYING
%doc README.rst
%{_bindir}/%{name}
%{_bindir}/gks-qrcode
%{_datadir}/applications/org.gnome.Keysign.desktop
%{_datadir}/metainfo/org.gnome.Keysign.appdata.xml
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Keysign.svg
%{python3_sitelib}/keysign/
%{python3_sitelib}/gnome_keysign-*.egg-info/

%changelog
* Mon Oct 21 2019 Andreas Schwab <schwab@suse.de>
- Correct dependency on gstreamer plugin
* Sun Jun 17 2018 bjorn.lie@gmail.com
- Update to version 0.9.7.2:
  + Change desktop ID.
  + Save appdata in share/metainfo.
- Changes from version 0.9.7.1:
  + Generate appdata with XML declaration.
- Changes from version 0.9.7:
  + Fixed icon, desktop, and appdata file names to match appid.
  + Support for running as a flatpak app, i.e. making use of email
    portal.
  + Handle gpgme's "status_code_lost" if the agent on the host is
    old.
  + Handle gpgme's "INV_SGNR" for expired keys.
  + Fixed the detection of keys and the relevant homedir.
  + Now fully removed traces of monkeysign.
  + Fixed an encoding issue with Bluetooth under Python2.
  + Bluetooth should now really be optional.
  + Work around a crash in gpgme on 32bit.
- Drop python3-monkeysign sub-package.
* Mon Apr  9 2018 mgorse@suse.com
- Build for python 3. Adjust Requires, BuildRequires, and files
- Add gnome-keysign-python3-setup.patch: fix UnicodeDecodeError
  when processing translations.
- python-monkeysign -> python3-monkeysign.
* Thu Jan 11 2018 dimstar@opensuse.org
- Update to version 0.9.6:
  * Appdata: Updated format to newer standard.
  * added a primitive extract_desktop function to babelglade.
  * babelglade: add Python 3 support.
  * desktop extract: regard the desktop file spec for translatable
    strings.
  * removed our copy of monkeysign.
  * rewrote babelglade using lxml instead of expat.
  * send: avoid BT restart when back has been pressed.
  * setup.py: Generate translated desktop file.
  * setup.py: Let python setup.py test run "nosetest tests".
  * setup: group the catalogs in a separate function.
  * test_bluetooth: Skip tests if pybluez is not available.
  * test_gpgmks: skip the tests if mks is not available.
  * tests: Avoid too broad exception clause.
- Add python-lxml BuildRequires: new dependency used during
  translation of the xml files.
* Tue Oct  3 2017 tobiasmue@gnome.org
- Update to version 0.9.5:
  * Bluetooth support through BlueZ and Twisted
  * Translation support with Babel
  * Increased Python 3 compatibility
  * default to gpgme instead of monkeysign
  * Better resiliance for pathologic OpenPGP keys
- Drop python-monkeysign Requires: we switched to gpgme.
- Add python-Babel BuildRequires: new dependency for the
  translations.
- Add python-gpg, python-pybluez and python-twisted Requires: new
  dependencies.
* Fri May 26 2017 jmatejek@suse.com
- Add version on python-monkeysign Requires, ease updates for
  users. Can be lowered to a Recommends in the future.
- Drop no longer needed pushd/popd call.
* Thu May 11 2017 tobiasmue@gnome.org
- Update to version 0.9:
  * Widgets are now loaded from Glade files instead of
    created from Python code
  * The key downloader returns bytes rather than strings
  * Keyserver: Now using application/pgp-keys as MIME type
  * Barcode scanner: Removed GStreamer<1.6 compatibility
  * Barcode scanner: Moved to gtksink for reducing code
    and increasing compatibility with running in a VM
  * Barcode scanner: Moved to autovideosrc
  * Barcode scanner: Stopped logging every single message
  * ScalingImage: Respecting the height when calculating the scale
  * KeysPage: Renamed signals to match Gtk convention more closely
* Mon Jan 30 2017 tobiasmue@gnome.org
- Update to version 0.8:
  * GetKeySection: Timing the HTTP request out to make the UI
    respond more quickly.
  * gpgmh: Handle no existing private keys.
  * gpgmh: Made get_usable_keys not abort when no keys exist.
  * QRImage: Switching monitors on left or right key.
  * QRCode: Added a tooltip for the (non-fullscreen) QRImage.
  * Keyserver: Defined the poll_interval to be 0.15 instead of the
    default 0.5.
  * Added a graphical exception hook.
  * gpgmeh: Added a gpgme based gpg library.
  * gpgmh: Conditionally load new gpg library with KEYSIGN_GPGME.
- Drop gnome-keysign-gpg-2.1-returncode.patch and
  gnome-keysign-gpg-2.1.patch: upstream now supports gpg 2.1.
- Require python-setuptools: it's a runtime dependency too.
* Sat Oct 22 2016 tobiasmue@gnome.org
- Update to version 0.7:
  * Changed QR code to include an uppercase MAC.
  * UI improvements.
  * Logging improvements.
  * Refactored and deduplicated code.
  * Increased Python3 compatbility.
* Thu Jul  7 2016 tobiasmue@gnome.org
- Update to version 0.6:
  * GetKey: Properly call TempKeyring, not TemporaryKeyring
  * Using gi.require for Gtk, Gst, and GstVideo
  * Increased py3k compatibilty
- Add gnome-keysign-gpg-2.1-returncode.patch: Improve GPG 2.1
  compatibility. Patch has been submitted to monkeysign upstream:
  https://lists.riseup.net/www/arc/monkeysphere/2016-07/msg00000.html
* Sat Jun 25 2016 dimstar@opensuse.org
- Add python-requests Requires: manadatory dependency.
* Thu Jun 16 2016 dimstar@opensuse.org
- Add gnome-keysign-gpg-2.1.patch: Fix executiong with GPG 2.1.
  Patch has been submitted to monkeysign upstream.
* Thu Jun 16 2016 dimstar@opensuse.org
- Initial package, version 0.5.
